#!/usr/bin/env python
import os, json
from yac.yaccli.lib.config import get_config_path

def create_stack():

	std_stack_path = os.path.join(get_config_path(),'yac-stack.json')

	file_found = os.path.exists(std_stack_path)

	print "loading stack def from %s. file exists? %s"%(std_stack_path,file_found)

	return "stack print complete"


import argparse
from yac.yaccli.lib.stack import create_stack

def main():

    parser = argparse.ArgumentParser('Print a stack for an Atlassian application via cloudformation')
    # required args
    parser.add_argument('app',  help='name of the app to build stack for', 
                                choices=['jira','crowd','confluence','bamboo','stash','hipchat'])
    parser.add_argument('env',  help='the env', 
                                choices=['dev', 'stage', 'prod','archive'])

    # optional
    # store_true allows user to not pass a value (default to true, false, etc.)
    parser.add_argument('-c','--create',  
                        help='create a new stack rather than updating existing (defaults to false)', 
                        action='store_true')

    args = parser.parse_args()

    return create_stack()


import argparse,sys
import yac.yaccli.stack

def yac_options(string):
    # options can be most anything. Let the 
    # sub-functions argparse handle validation
    return string

def main():

    parser = argparse.ArgumentParser('Your Atlassian Cloud',add_help=False)
    
    # required args
    parser.add_argument('operation',  
                        help='the yac operation to perform', 
                        choices=['stack','app','db','container'])
    
    parser.add_argument('option', 
                        help='options',
                        nargs='*',
                        type=yac_options)

    # trap -h. let operations handle most of the help
    parser.add_argument('-h', action='store_true')

    args = parser.parse_args()

    # strip operation from args list
    sys.argv = sys.argv[1:]

    if args.operation == 'stack':

        return yac.yaccli.stack.main()

    else:

        return "operation not yet implemented"
        